@@ -2,8 +2,6 @@
 
 ;;; Code:
 
-(autoload 'custom-add-loads "cus-load")
-
 (custom-add-loads 'cperl '("cperl-mode"))
 (custom-add-loads 'prolog '("prolog"))
 (custom-add-loads 'pascal '("pascal"))
@@ -34,6 +32,7 @@
 (custom-add-loads 'compilation-elisp '("mode-compile"))
 (custom-add-loads 'compilation '("mode-compile"))
 (custom-add-loads 'SQL '("sql"))
+(custom-add-loads 'makemode '("make-mode"))
 (custom-add-loads 'vrml '("vrml-mode"))
 (custom-add-loads 'simula '("simula"))
 (custom-add-loads 'compile-java '("mode-compile"))
@@ -44,6 +43,7 @@
 (custom-add-loads 'cperl-faces '("cperl-mode"))
 (custom-add-loads 'languages '("asm-mode" "cperl-mode" "fortran" "icon" "mode-compile" "pascal" "prolog" "python-mode" "rexx-mode" "simula" "tcl" "verilog-mode" "vrml-mode"))
 (custom-add-loads 'compilation-lang '("mode-compile"))
+(custom-add-loads 'faces '("make-mode"))
 (custom-add-loads 'cperl-help-system '("cperl-mode"))
 (custom-add-loads 'compile-zsh '("mode-compile"))
 (custom-add-loads 'processes '("sql"))
